;; Generated package description from embark.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "embark" "1.2.0.20260609.21" "Conveniently act on minibuffer completions" '((emacs "29.1") (compat "31")) :commit "350ca86924c5027e80875943fba7b912a71e5791" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("convenience") :url "https://github.com/oantolin/embark")
